@@ -6,6 +6,7 @@
 #'        in this case the strings are returned as characters.
 #' @param bulk a logical value with default value \code{TRUE} if the input SDMX XML file is from the bulk download facility containing all the observations. 
 #'        If the input file has pre-filtered values then the value \code{FALSE} should be used.  
+#' @param check_toc if the data file was downloaded using the URL from the TOC or not. The default is FALSE means not the TOC link is used.         
 #' @export 
 #' @details It is a sub-function to use in the \code{\link{get_eurostat_data}} and the \code{\link{get_eurostat_raw}} functions.
 #' @return a data frame containing the values of an SDMX node: the dimensions, value and the optional flag(s)
@@ -35,20 +36,22 @@
 #' }
 #' 
 
-extract_data<-function(xml_lf,keep_flags=FALSE,stringsAsFactors=FALSE,bulk=TRUE){
-  prefix<-NULL
-  if (Sys.info()[['sysname']]=='Windows'){
-    xml_lf<-gsub("generic:","",xml_lf)
-    xml_lf<-xml2::as_xml_document(xml_lf)
-  } else {
-    prefix<-"generic:"
-  }
+extract_data<-function(xml_lf,keep_flags=FALSE,stringsAsFactors=FALSE,bulk=TRUE,check_toc=FALSE){
+  if (getOption("restatapi_verbose",FALSE))  {message("\nextract_data - API version:",get("rav",envir=restatapi::.restatapi_env))}
+  rav<-get("rav",envir=restatapi::.restatapi_env)
+  prefix<-switch(rav,"1"="generic:","2"="g:")
   if(bulk){
+    if (Sys.info()[['sysname']]=='Windows'){
+      xml_lf<-gsub(prefix,"",xml_lf)
+      xml_lf<-xml2::as_xml_document(xml_lf)
+    } 
     bd<-t(as.data.frame(xml2::xml_attrs(xml_lf),stringsAsFactors=FALSE))
     rownames(bd)<-NULL
     dv<-xml2::xml_attrs(xml2::xml_children(xml_lf))
     if (keep_flags){
-      cn<-c("TIME_PERIOD","OBS_VALUE","OBS_STATUS")
+      flagc<-switch(rav,"1"="OBS_STATUS","2"="OBS_FLAG")
+      if (check_toc) {flagc<-"OBS_STATUS"}
+      cn<-c("TIME_PERIOD","OBS_VALUE",flagc)
     } else {
       cn<-c("TIME_PERIOD","OBS_VALUE")
     }
@@ -56,14 +59,18 @@ extract_data<-function(xml_lf,keep_flags=FALSE,stringsAsFactors=FALSE,bulk=TRUE)
     colnames(df)<-cn
     out<-data.frame(bd,df,stringsAsFactors=FALSE)  
   } else {
+    # if (Sys.info()[['sysname']]=='Windows'){
+    #   xml_lf<-xml2::as_xml_document(xml_lf)
+    # } 
     tmp<-as.data.frame(xml2::xml_attrs(xml2::xml_children(xml2::xml_find_all(xml_lf,paste0(".//",prefix,"SeriesKey")))),stringsAsFactors=FALSE)
     bd<-as.data.frame(tmp[2,],stringsAsFactors=FALSE)
     colnames(bd)<-tmp[1,]
     rownames(bd)<-NULL
     obs<-xml2::xml_find_all(xml_lf,paste0(".//",prefix,"Obs"))
     cn<-c("obsTime","obsValue") 
-    df<-data.table::rbindlist(lapply(obs, function(x) {dr<-as.data.frame(t(unlist(xml2::xml_attrs(xml2::xml_children(x),"value"))),stringsAsFactors=FALSE)
+    df<-data.table::rbindlist(lapply(obs, function(x) {dr<-as.data.frame(t(unlist(xml2::xml_attrs(xml2::xml_children(x)))),stringsAsFactors=FALSE)
                                                 rownames(dr)<-NULL
+                                                if (ncol(dr)<2) {dr$nc<-""}
                                                 colnames(dr)<-cn
                                                 if ((keep_flags)){
                                                   f<-xml2::xml_attr(xml2::xml_children(xml2::xml_children(x)),"value")
@@ -85,4 +92,4 @@ extract_data<-function(xml_lf,keep_flags=FALSE,stringsAsFactors=FALSE,bulk=TRUE)
     }
   }
   return(out)
-}
\ No newline at end of file
+}
